==> openser-1.2.1-tls_src.tar.gz: openser-1.2.1-tls/modules/seas/encode_msg.h <==
/* $Id: encode_msg.h 1827 2007-03-12 15:22:53Z bogdan_iancu $
 *
 * Copyright (C) 2006-2007 VozTelecom Sistemas S.L
 *
 * This file is part of openser, a free SIP server.
 *
 * openser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * openser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "../../parser/hf.h"
#include "../../parser/msg_parser.h"

#define MAX_ERROR 32
#define MAX_HEADERS 32
#define MAX_ENCODED_MSG 1500
#define MAX_MESSAGE_LEN 1500

#define TYPE_IDX 0
#define MSG_START_IDX 	(TYPE_IDX+2)
#define MSG_LEN_IDX 	(MSG_START_IDX+2)
#define CONTENT_IDX 	(MSG_LEN_IDX+2)
#define METHOD_CODE_IDX (CONTENT_IDX+2)
#define URI_REASON_IDX 	(METHOD_CODE_IDX+2)
#define VERSION_IDX 	(URI_REASON_IDX+2)
#define REQUEST_URI_IDX (VERSION_IDX+2)

#define GET_PAY_SIZE( A ) (ntohs(((short*)( A ))[1]) + ntohs(((short*)( A ))[2]))
char get_header_code(struct hdr_field *f);
int encode_msg(struct sip_msg *msg,char *payload,int len);
int print_encoded_msg(int fd,char *code,char *prefix);
int dump_msg_test(char *code,int fd,char header,char segregationLevel);
extern unsigned int theSignal;

==> openser-1.2.2-tls_src.tar.gz: openser-1.2.2-tls/modules/seas/encode_msg.h <==
/* $Id: encode_msg.h 2333 2007-06-04 17:59:05Z eliasbaixas $
 *
 * Copyright (C) 2006-2007 VozTelecom Sistemas S.L
 *
 * This file is part of openser, a free SIP server.
 *
 * openser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * openser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "../../parser/hf.h"
#include "../../parser/msg_parser.h"

#define MAX_ERROR 32
#define MAX_HEADERS 32
#define MAX_ENCODED_MSG 1500
#define MAX_MESSAGE_LEN 1500

#define TYPE_IDX 0
#define MSG_START_IDX 	(TYPE_IDX+2) /*2*/
#define MSG_LEN_IDX 	(MSG_START_IDX+2) /*4*/
#define CONTENT_IDX 	(MSG_LEN_IDX+2) /*6*/
#define METHOD_CODE_IDX (CONTENT_IDX+2) /*8*/
#define URI_REASON_IDX 	(METHOD_CODE_IDX+2) /*10*/
#define VERSION_IDX 	(URI_REASON_IDX+2) /*12*/
#define REQUEST_URI_IDX (VERSION_IDX+2) /*14*/

#define GET_PAY_SIZE( A ) (ntohs(((short*)( A ))[1]) + ntohs(((short*)( A ))[2]))
char get_header_code(struct hdr_field *f);
int encode_msg(struct sip_msg *msg,char *payload,int len);
int print_encoded_msg(int fd,char *code,char *prefix);
int dump_msg_test(char *code,int fd,char header,char segregationLevel);
extern unsigned int theSignal;
